# Changelog

## v0.5.8

<!-- Release notes generated using configuration in .github/release.yml at main -->

## What's Changed
### 🚀 New Features
* Improve calc quality analysis implementation by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/406
* Expose chemenv attributes and misc cli, featurizer enhancements by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/409
* Update featurizer by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/420
### 🐛 Bug Fixes
* update test durations by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/405
* Fix cli inconsistency by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/423
### 🧹 House-Keeping
* Update pre-commit config and address ruff import errors by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/408
### 🔄 Other Changes
* Bump myst-nb from 1.2.0 to 1.3.0 by @dependabot[bot] in https://github.com/JaGeo/LobsterPy/pull/411
* Bump sphinx-toolbox from 4.1.0 to 4.1.1 by @dependabot[bot] in https://github.com/JaGeo/LobsterPy/pull/422


**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.5.7...v0.5.8


## v0.5.7

<!-- Release notes generated using configuration in .github/release.yml at main -->

## What's Changed
### 🚀 New Features
* fix sitewise bwdf by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/388
### 🐛 Bug Fixes
* Fix ICOHPDistance plotter  by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/401


**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.5.6...v0.5.7


## v0.5.6

<!-- Release notes generated using configuration in .github/release.yml at main -->

## What's Changed
### 🧹 House-Keeping
* Fix bloated src distribution on pypi by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/385
### 🔄 Other Changes
* remove explicit reading of DOSCAR.LSO.lobster by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/397


**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.5.5...v0.5.6


## v0.5.5

<!-- Release notes generated using configuration in .github/release.yml at main -->

## What's Changed
### 🐛 Bug Fixes
* Update plotly test data by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/369
* fix vasprun.xml gz file issue by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/376
* Fix optional dependencies related errors by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/383
### 🧹 House-Keeping
* CI updates by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/377
### 🔄 Other Changes
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/366


**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.5.4...v0.5.5


## v0.5.4
Same as v0.5.3. with correct dependencies

### What's Changed
* Fix dependencies by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/364

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.5.3...v0.5.4

## v0.5.3
Same as v0.5.1. Version number in 0.5.1 wasn't updated correctly

## v0.5.1

### What's Changed
* Enhance icoxxlist plotter by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/343
* Update README.md by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/345
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/346
* `matplotlib` use non-interactive agg backend by @DanielYang59 in https://github.com/JaGeo/LobsterPy/pull/349
* Bump mendeleev from 0.18.1 to 0.19.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/347
* Misc ci updates by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/350
* fix artifacts version inconsistency by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/352
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/353
* Add new functions/methods to featurize module by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/330
* Update test durations file by @github-actions in https://github.com/JaGeo/LobsterPy/pull/354
* Bump mendeleev from 0.19.0 to 0.20.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/356
* Bump mendeleev from 0.20.0 to 0.20.1 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/358
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/359
* Cli updates by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/357
* Fix codecov failure by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/361

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.5.0...v0.5.1


## v0.5.0
### What's Changed
* Update CHANGELOG.md by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/334
* Ci updates by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/341
* Update get struct path by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/340
* Bump mendeleev from 0.17.0 to 0.18.1 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/338
* Bump sphinx-toolbox from 3.8.0 to 3.8.1 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/339
* Bump myst-nb from 1.1.1 to 1.1.2 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/335
* pin min pymatgen version > lobster 5.0/5.1 support by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/342

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.9...v0.5.0

## v0.4.9
### What's Changed
* Same as v0.4.8 which did not get released on pypi due to an issue with the release workflow

## v0.4.8
### What's Changed
* change python version from 3.9 to 3.10 in docs generation by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/322
* Bump sphinx-design from 0.6.0 to 0.6.1 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/324
* Bump sphinx-toolbox from 3.7.0 to 3.8.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/326
* Update sphinx requirement from <8,>=5 to >=5,<9 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/323
* Update calc quality and fingerprints usage by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/331
* Remove redundant coverage uploads and fix coverage reports by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/332
* Fix the path of lobsterenv.py. by @hongyi-zhao in https://github.com/JaGeo/LobsterPy/pull/333

### New Contributors
* @hongyi-zhao made their first contribution in https://github.com/JaGeo/LobsterPy/pull/333

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.7...v0.4.8


## v0.4.7
* fix outdated cli tutorial code snippets by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/320
* Fix unexpected "DOSCAR.LSO.lobster" exception in cli  by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/321

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.6...v0.4.7

## v0.4.6
* CI Updates by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/314
* Move to src layout by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/315
* Bump sphinx-toolbox from 3.6.0 to 3.7.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/313

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.5...v0.4.6

## v0.4.5
* Bump mendeleev from 0.15.0 to 0.16.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/288
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/289
* Bump mendeleev from 0.16.0 to 0.16.1 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/290
* Bump mendeleev from 0.16.1 to 0.16.2 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/291
* Bump sphinx-design from 0.5.0 to 0.6.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/292
* Bump mendeleev from 0.16.2 to 0.17.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/296
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/294
* Bump sphinx-book-theme from 1.1.2 to 1.1.3 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/298
* Fix warnings by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/299
* Update readme by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/302
* Explicitly use `agg` backend to avoid OS inconsistency by @DanielYang59 in https://github.com/JaGeo/LobsterPy/pull/305
* Update orbitalwise analysis by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/300
* Update numpy requirement from <2.0.0 to <3.0.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/309
* Bump sphinx-toolbox from 3.5.0 to 3.6.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/310
* Bump myst-nb from 1.1.0 to 1.1.1 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/311
* clarify kpoints requirements and limitations with input sets by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/307

### New Contributors
* @DanielYang59 made their first contribution in https://github.com/JaGeo/LobsterPy/pull/305

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.4...v0.4.5

## v0.4.4
* No changes compared to 0.4.3. Just an error with the deployment occurred.

## v0.4.3
* Update sphinx requirement from <6,>=5 to >=5,<8 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/281
* Python 3.12 support by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/282

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.2...v0.4.3

## v0.4.2
* Add preliminary support multicobi by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/277

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.1...v0.4.2

## v0.4.1
* clean up DOSCAR.LSO.lobster handling and add cli test for POSCAR.lobster by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/257
* Fix saving of plots by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/262
* fix linting by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/263
* fix automatic plotting for large structures by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/265
* Update README.md by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/266
* Update README.md by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/267
* add code of conduct by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/268
* pre-commit autoupdate by @pre-commit-ci in https://github.com/JaGeo/LobsterPy/pull/270
* indicate python versions correctly. by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/271
* Update pymatgen version  by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/273
* Bump myst-nb from 1.0.0 to 1.1.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/274
* Update pyproject.toml by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/275

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.4.0...v0.4.1

## v0.4.0
* Fix cli bug, enable spin polarized interactive analysis in cli by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/256

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.3.9...v0.4.0
## v0.3.9
* Add JOSS badge by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/248
* Add note about dummy potcar to example file by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/249
* Fix link to changelog by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/250
* Fix citation and readme by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/251
* remove redundant orbplot arg and fix a typo by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/253

## v0.3.8
* Add Contributing guide to Readme by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/224
* address review comments > LOBSTER citation, similar packages by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/226
* add missing , by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/227
* Bump sphinx-book-theme from 1.1.0 to 1.1.2 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/230
* tutorial: replace os with pathlib.Path by @berquist in https://github.com/JaGeo/LobsterPy/pull/231
* Review 2 suggestion by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/234
* Accommodate LobsterEnv breaking changes by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/232
* Configuration consolidation by @berquist in https://github.com/JaGeo/LobsterPy/pull/235
* Add coverage report by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/238
* Update README.md by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/239
* Add precommit badge by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/240
* Analysis extend + adapt to latest changes in LobterEnv by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/233
* Add explanation to cli help by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/244
* File path handling in featurizer module by @kaueltzen in https://github.com/JaGeo/LobsterPy/pull/242
* Add cutoff args to batch structure graphs featurizer by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/245
* [JOSS] Paper nitpicks by @RMeli in https://github.com/JaGeo/LobsterPy/pull/247
* Update readme and paper.md by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/246

## v0.3.7
* Set python version stricter limit and accommodate recent pymatgen changes by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/222

## v0.3.6
* JOSS paper by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/203

## v0.3.5
* Fix header by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/189
* WIP[fix interactive plots] by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/190
* Update docs.yml by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/191
* Update docs.yml by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/192
* Update docs.yml by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/194
* Update conf.py by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/195
* Update tutorial.ipynb by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/196
* Update tutorial.ipynb by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/197
* Update tutorial.ipynb by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/198
* Update tutorial.ipynb by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/199
* Update conf.py by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/200
* Fix blank interactive plots by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/201
* Fix typos and grammatical errors by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/202
* Minor documentation fixes by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/206
* address doc review comments by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/208
* Bump mendeleev from 0.14.0 to 0.15.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/211
* Bump myst-nb from 0.17.2 to 1.0.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/204
* Bump ipython from 8.16.1 to 8.19.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/209
* Bump sphinx-book-theme from 1.0.1 to 1.1.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/210
* Fix doc by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/213
* Remove redundant ipython from doc dependencies by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/216
* Fix: text generation error when no bonds are detected at site in cation-anion analysis by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/217


**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.3.4...v0.3.5


## v0.3.4
- fix changelog by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/188
- Update documentation by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/180

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.3.3...v0.3.4

## v0.3.3
- fixing which_bonds  by @JonasGrandel in https://github.com/JaGeo/LobsterPy/pull/168
- fix create inputs alias not working; update test for the same by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/171
- Automatic orbital wise analysis functionality in analyze module by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/132
- Replace unittests with pytests + update CI workflow and code doc-strings by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/177
- replace get_anion_types with anion_types by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/174
- rename keys of calc quality summary and snake_case by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/178
- Remove read the docs config  by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/182
- Refactor cli.py for cleaner options on cli help by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/172
- overwrite add_cohp for interactive plotter > Now it works as expected by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/176
- Extend featurizer by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/179
- Update README.md by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/184
- Increase test coverage by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/185
- add POSCAR.lobster support in featurizer by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/186

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.3.2...v0.3.3

## v0.3.2
- cli invert axis, add get site all orbitals dos plot by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/149
- Update README.md by @JaGeo in https://github.com/JaGeo/LobsterPy/pull/150
- Bump mendeleev from 0.12.1 to 0.14.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/151
- snakecase key names of calc quality summary dict by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/157
- Fix missing matplotlib style file in package installation  by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/159
- snakecase whichbonds arg and update tests by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/161

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.3.1...v0.3.2

## v0.3.1
- ICOHP vs bond length plotter by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/137
- Remove python 3.8 support by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/134
- Add units to plotters by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/136
- Bump sphinx-pdj-theme from 0.2.1 to 0.4.0 by @dependabot in https://github.com/JaGeo/LobsterPy/pull/111
- Doscar plotting by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/138
- added lobster calc quality summary method to analyze module by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/115
- Add featurizer by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/102
- COBI COOP extension by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/128
- Structure graphs by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/63
- fix docs build, remove unwanted dependencies by @naik-aakash in https://github.com/JaGeo/LobsterPy/pull/146

**Full Changelog**: https://github.com/JaGeo/LobsterPy/compare/v0.3.0...v0.3.1

## v0.3.0
- addition of an interactive plotter by @naik-aakash and @kaueltzen. Reviews by @ajjackson and @jageo
## v0.2.9
- fix the error handling in cases ChemEnv cannot determine a coordination environment and we use coordination numbers instead for the cation-anion mode

## v0.2.8
- fix issue while saving files

## v0.2.7
- compatible with atomate2
## v0.2.5
- compatible with latest pymatgen version
## v0.2.4
- fixing linting errors due to new mypy versions
## v0.2.3
- bonding and antibonding contributions will now be integrated and a percentage of antibonding interactions below Efermi will be given.

## v0.2.2
- users can provide their own basis functions for lobsterin/INCAR generation
- documentation added
- fixes to saving files

## v0.2.1
- Fix error message when LobsterPy is used in cation-anion mode for materials that are not ionic.
- automatic plots are now saved correctly. Before only the last plot was saved.
- Additional Gaussian broadening available for COHPs
- lobsterins can be generated with the command-line interface
## v0.1.0
- First LobsterPy release
- Automatic COHP analysis (description and plots)
- Command line tool to perform automatic analysis
- Command line tool to plot COHPs, COOPs, and COBIs - also orbitalwise and summed
- Many options to refine plots (own matplotlib styles, changes of font size, sizes)
